[![PyPI - Implementation](https://img.shields.io/pypi/v/g2o-python)](https://pypi.org/project/g2o-python/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/g2o-python)](https://pypi.org/project/g2o-python/)


# g2o-python

This is a wrapper of the python binding of [g2o](https://github.com/RainerKuemmerle/g2o) using its branch `pymem`.
